# redcat

<p align="center">
    <a href="https://github.com/durandtibo/redcat/actions">
        <img alt="CI" src="https://github.com/durandtibo/redcat/workflows/CI/badge.svg?event=push&branch=main">
    </a>
    <a href="https://durandtibo.github.io/redcat/">
        <img alt="CI" src="https://github.com/durandtibo/redcat/workflows/Documentation/badge.svg?event=push&branch=main">
    </a>
    <a href="https://codecov.io/gh/durandtibo/redcat">
        <img alt="Codecov" src="https://codecov.io/gh/durandtibo/redcat/branch/main/graph/badge.svg">
    </a>
    <a href="https://codeclimate.com/github/durandtibo/redcat/maintainability">
        <img src="https://api.codeclimate.com/v1/badges/0987ab26fe4d52025085/maintainability" />
    </a>
    <a href="https://codeclimate.com/github/durandtibo/redcat/test_coverage">
        <img src="https://api.codeclimate.com/v1/badges/0987ab26fe4d52025085/test_coverage" />
    </a>
    <br/>
    <a href="https://pypi.org/project/redcat/">
        <img alt="PYPI version" src="https://img.shields.io/pypi/v/redcat">
    </a>
    <a href="https://pypi.org/project/redcat/">
        <img alt="Python" src="https://img.shields.io/pypi/pyversions/redcat.svg">
    </a>
    <a href="https://opensource.org/licenses/BSD-3-Clause">
        <img alt="BSD-3-Clause" src="https://img.shields.io/pypi/l/redcat">
    </a>
    <a href="https://github.com/psf/black">
        <img  alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg">
    </a>
    <a href="https://google.github.io/styleguide/pyguide.html#s3.8-comments-and-docstrings">
        <img  alt="Doc style: google" src="https://img.shields.io/badge/%20style-google-3666d6.svg">
    </a>
    <br/>
    <a href="https://pepy.tech/project/redcat">
        <img  alt="Downloads" src="https://static.pepy.tech/badge/redcat">
    </a>
    <a href="https://pepy.tech/project/redcat">
        <img  alt="Monthly downloads" src="https://static.pepy.tech/badge/redcat/month">
    </a>
    <br/>
</p>

<p align="center">
<img height="242" src="assets/redcat.png" alt="logo"/>
</p>

---

*The logo was generated with Stable Diffusion 2.1*
